/* Copyright 2021 Dominik George <nik@naturalnet.de>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

const eventNamespace = 'team.auglement.augmentile';
const EventTypes = {
  map: eventNamespace + '.map',
  player: eventNamespace + '.player',
};

class BaseBackend {
  constructor(userId) {
    this.userId = userId;
  }

  setMapData(mapData) {
    this.game.loadMap(mapData);
  }

  setMapDataFromUrl(url) {
    if (url.substr(0, 6) === 'mxc://') {
      url = this.resolveMxcUrl(url);
    }

    fetch(url)
        .then((response) => response.json())
        .then(this.setMapData);
  }

  getMap(mapName) {
    if (mapName.indexOf('://') > -1) {
      this.setMapDataFromUrl(mapName);
    } else {
      const state = this.getState(EventTypes.map, mapName);
      if (state.url !== undefined) {
        this.setMapDataFromUrl(state.url);
      } else {
        this.setMapData(state);
      }
    }
  }
}

export default BaseBackend;
export {EventTypes, BaseBackend};
