/* Copyright 2021 Dominik George <nik@naturalnet.de>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * Split a Matrix ID into local part and homeserver
 *
 * @param {string} matrixId
 * @return {Object}
 *
 * @example
 *   splitMatrixId('@foo:example.com')
 *   // => {'localPart': 'foo', 'homeServer': 'example.com'}
 */
export function splitMatrixId(matrixId) {
  if (typeof matrixId !== 'string') {
    throw new Error('Passed Matrix ID must be a string');
  } else if (matrixId.substr(0, 1) !== '@') {
    throw new Error('Passed Matrix ID must begin with @');
  } else if (matrixId.indexOf(':') < 2) {
    throw new Error('Passed Matrix ID must contain :');
  }

  const localPart = matrixId.substr(1).substr(0, matrixId.indexOf(':'));
  const homeServer = matrixId.substr(matrixId.indexOf(':') + 1);

  return {
    'localPart': localPart,
    'homeServer': homeServer,
  };
}
